==> lxqt-runner_1.2.0.orig.tar.xz: lxqt-runner-1.2.0/translations/lxqt-runner_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Käivitaja seadistused</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Välimus</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Paigutus:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Show on:</source>
        <translation>Asukoht:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="46"/>
        <source>Show history first</source>
        <translation>Näita ajalugu esimesena</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="53"/>
        <source>Store/show history</source>
        <translation>Salvesta ja näita ajalugu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="60"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Märkus&lt;/b&gt;: Ülataseme vidinate suurus on piiratud kahe kolmandikuga töölaua kõrgusest ja laiusest.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="63"/>
        <source>Show list with:</source>
        <translation>Otsingutulemuste arv:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="70"/>
        <source> item(s)</source>
        <translation> kirje(t)</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="80"/>
        <source>Clear input on launching</source>
        <translation>Käivitamisel kustuta sisestatud andmed</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="97"/>
        <source>Shortcut:</source>
        <translation>Kiirklahv:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Ekraani ülaosas</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Ekraani keskel</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>Ekraanil, mis on fookuses</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Alati ekraanil %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Lähtesta</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Rakenduste käivitaja </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="105"/>
        <source>Configure</source>
        <translation>Seadistused</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="109"/>
        <source>Clear History</source>
        <translation>Kustuta otsingute ajalugu</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="408"/>
        <source>Show/hide runner dialog</source>
        <translation>Näita või peida rakenduste käivitaja</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Ajalugu</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="846"/>
        <source>Copy calculation result to clipboard</source>
        <translation>Kopeeri arvutustulemus lõikelauale</translation>
    </message>
</context>
</TS>

==> lxqt-runner_1.4.0.orig.tar.xz: lxqt-runner-1.4.0/translations/lxqt-runner_et.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="et">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Käivitaja seadistused</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Välimus</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Paigutus:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Top margin</source>
        <translation>Ülemine veeris</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="43"/>
        <source> px</source>
        <translation> pikslit</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="50"/>
        <source>Show on:</source>
        <translation>Asukoht:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="60"/>
        <source>Show history first</source>
        <translation>Näita ajalugu esimesena</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="67"/>
        <source>Store/show history</source>
        <translation>Salvesta ja näita ajalugu</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="74"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Märkus&lt;/b&gt;: Ülataseme vidinate suurus on piiratud kahe kolmandikuga töölaua kõrgusest ja laiusest.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="77"/>
        <source>Show list with:</source>
        <translation>Otsingutulemuste arv:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="84"/>
        <source> item(s)</source>
        <translation> kirje(t)</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="94"/>
        <source>Clear input on launching</source>
        <translation>Käivitamisel kustuta sisestatud andmed</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="111"/>
        <source>Shortcut:</source>
        <translation>Kiirklahv:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Ekraani ülaosas</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Ekraani keskel</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="67"/>
        <source>Focused screen</source>
        <translation>Ekraanil, mis on fookuses</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>Always on screen %1</source>
        <translation>Alati ekraanil %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="80"/>
        <source>Reset</source>
        <translation>Lähtesta</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Rakenduste käivitaja </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="106"/>
        <source>Configure</source>
        <translation>Seadistused</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="110"/>
        <source>Clear History</source>
        <translation>Kustuta otsingute ajalugu</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="409"/>
        <source>Show/hide runner dialog</source>
        <translation>Näita või peida rakenduste käivitaja</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Ajalugu</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="846"/>
        <source>Copy calculation result to clipboard</source>
        <translation>Kopeeri arvutustulemus lõikelauale</translation>
    </message>
</context>
</TS>
